==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface StressChaosFluent<A extends StressChaosFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public StressChaosFluent.MetadataNested<A> withNewMetadata();
    public StressChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public StressChaosFluent.MetadataNested<A> editMetadata();
    public StressChaosFluent.MetadataNested<A> editOrNewMetadata();
    public StressChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public StressChaosSpec getSpec();
    public StressChaosSpec buildSpec();
    public A withSpec(StressChaosSpec spec);
    public Boolean hasSpec();
    public StressChaosFluent.SpecNested<A> withNewSpec();
    public StressChaosFluent.SpecNested<A> withNewSpecLike(StressChaosSpec item);
    public StressChaosFluent.SpecNested<A> editSpec();
    public StressChaosFluent.SpecNested<A> editOrNewSpec();
    public StressChaosFluent.SpecNested<A> editOrNewSpecLike(StressChaosSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public StressChaosStatus getStatus();
    public StressChaosStatus buildStatus();
    public A withStatus(StressChaosStatus status);
    public Boolean hasStatus();
    public StressChaosFluent.StatusNested<A> withNewStatus();
    public StressChaosFluent.StatusNested<A> withNewStatusLike(StressChaosStatus item);
    public StressChaosFluent.StatusNested<A> editStatus();
    public StressChaosFluent.StatusNested<A> editOrNewStatus();
    public StressChaosFluent.StatusNested<A> editOrNewStatusLike(StressChaosStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<StressChaosFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StressChaosSpecFluent<StressChaosFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StressChaosStatusFluent<StressChaosFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface StressChaosFluent<A extends StressChaosFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public StressChaosFluent.MetadataNested<A> withNewMetadata();
    public StressChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public StressChaosFluent.MetadataNested<A> editMetadata();
    public StressChaosFluent.MetadataNested<A> editOrNewMetadata();
    public StressChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public StressChaosSpec getSpec();
    public StressChaosSpec buildSpec();
    public A withSpec(StressChaosSpec spec);
    public Boolean hasSpec();
    public StressChaosFluent.SpecNested<A> withNewSpec();
    public StressChaosFluent.SpecNested<A> withNewSpecLike(StressChaosSpec item);
    public StressChaosFluent.SpecNested<A> editSpec();
    public StressChaosFluent.SpecNested<A> editOrNewSpec();
    public StressChaosFluent.SpecNested<A> editOrNewSpecLike(StressChaosSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public StressChaosStatus getStatus();
    public StressChaosStatus buildStatus();
    public A withStatus(StressChaosStatus status);
    public Boolean hasStatus();
    public StressChaosFluent.StatusNested<A> withNewStatus();
    public StressChaosFluent.StatusNested<A> withNewStatusLike(StressChaosStatus item);
    public StressChaosFluent.StatusNested<A> editStatus();
    public StressChaosFluent.StatusNested<A> editOrNewStatus();
    public StressChaosFluent.StatusNested<A> editOrNewStatusLike(StressChaosStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<StressChaosFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StressChaosSpecFluent<StressChaosFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StressChaosStatusFluent<StressChaosFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
